# Calculon
This project is a customizable implementation of the producer-consumer pattern using Python's multithreading and multiprocessing capabilities. Calculon allows you to:

* define a custom producer that puts values into a queue;
* define a custom consumer that processes values obtained from the queue;
* choose between multiprocessing or multithreading option to run the functions;
* pass arbitrary information to and back from each of the producer / consumer;

This package will be helpful to someone who is looking to use a producer-consumer
pattern to perform simple parallel computing tasks.

# Documentation
Documentation is hosted on [Read the Docs] (https://calculon.readthedocs.org/en/latest) and includes detailed information on installing and using the package.

# License
This project was released under MIT license, see **LICENSE** file for more information.

# Release Notes
See RELEASE file for the release history.
